# ranzen

A python toolkit facilitating machine-learning experimentation.

[Documentation](https://wearepal.ai/ranzen/)

## Install

Run
```
pip install ranzen
```

or install directly from GitHub:
```
pip install git+https://github.com/predictive-analytics-lab/ranzen.git@main
```
